==> qtjambi-charts-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiCharts/QCandlestickModelMapper_shell.h <==
#ifndef QCANDLESTICKMODELMAPPER_SHELL_H
#define QCANDLESTICKMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qcandlestickmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qcandlestickseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QCandlestickModelMapper_shell : public QCandlestickModelMapper, public QtJambiShellInterface
{
public:
    QCandlestickModelMapper_shell(QObject* parent0 = nullptr);
    ~QCandlestickModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientation orientation() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCandlestickModelMapper_access : public QCandlestickModelMapper
{
    jint __qt_close_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_firstSetSection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_high_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_lastSetSection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_low_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_open_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setClose_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint close0);
    void __qt_setFirstSetSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint firstSetSection0);
    void __qt_setHigh_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint high0);
    void __qt_setLastSetSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint lastSetSection0);
    void __qt_setLow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint low0);
    void __qt_setOpen_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint open0);
    void __qt_setTimestamp_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timestamp0);
    jint __qt_timestamp_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_orientation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QCANDLESTICKMODELMAPPER_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiCharts/QCandlestickModelMapper_shell.h <==
#ifndef QCANDLESTICKMODELMAPPER_SHELL_H
#define QCANDLESTICKMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qcandlestickmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qcandlestickseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QCandlestickModelMapper_shell : public QCandlestickModelMapper, public QtJambiShellInterface
{
public:
    QCandlestickModelMapper_shell(QObject* parent0 = nullptr);
    ~QCandlestickModelMapper_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QCandlestickModelMapper_mshell;
    friend class QCandlestickModelMapper_oshell;
};


class QCandlestickModelMapper_mshell : public QCandlestickModelMapper_shell
{
public:
    using QCandlestickModelMapper_shell::QCandlestickModelMapper_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QCandlestickModelMapper_oshell : public QCandlestickModelMapper_mshell
{
public:
    using QCandlestickModelMapper_mshell::QCandlestickModelMapper_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientation orientation() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCandlestickModelMapper_access : public QCandlestickModelMapper
{
    jint __qt_close_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_firstSetSection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_high_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_lastSetSection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_low_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_open_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setClose_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint close0);
    void __qt_setFirstSetSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint firstSetSection0);
    void __qt_setHigh_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint high0);
    void __qt_setLastSetSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint lastSetSection0);
    void __qt_setLow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint low0);
    void __qt_setOpen_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint open0);
    void __qt_setTimestamp_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timestamp0);
    jint __qt_timestamp_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_orientation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QCANDLESTICKMODELMAPPER_SHELL_H
